# mpl-draggable-line

[![License](https://img.shields.io/pypi/l/mpl-draggable-line.svg?color=green)](https://github.com/ianhi/mpl-draggable-line/raw/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/mpl-draggable-line.svg?color=green)](https://pypi.org/project/mpl-draggable-line)
[![Python Version](https://img.shields.io/pypi/pyversions/mpl-draggable-line.svg?color=green)](https://python.org)
[![CI](https://github.com/ianhi/mpl-draggable-line/actions/workflows/ci/badge.svg)](https://github.com/ianhi/mpl-draggable-line/actions)
[![codecov](https://codecov.io/gh/ianhi/mpl-draggable-line/branch/master/graph/badge.svg)](https://codecov.io/gh/ianhi/mpl-draggable-line)

Draggable Line Widget for matplotlib

```bash
pip install mpl-draggable-line
```

![a line being dragged around in an empty plot](docs/_static/simple-demo.apng)

